unit MainFormU;

interface

uses
  System.SysUtils, System.Types, System.UITypes, System.Classes, System.Variants,
  FMX.Types, FMX.Controls, FMX.Forms, FMX.Graphics, FMX.Dialogs, FMX.StdCtrls, FMX.Layouts, FMX.ListBox, NFCHelper,
  FMX.Edit;

type
  TMainForm = class(TForm)
    NFCTagIdLabel: TLabel;
    InfoLabel: TLabel;
    TagWriteButton: TButton;
    TagWriteEdit: TEdit;
    procedure FormActivate(Sender: TObject);
    procedure TagWriteButtonClick(Sender: TObject);
  private
    { Private declarations }
  public
    { Public declarations }
  end;

var
  MainForm: TMainForm;

implementation

{$R *.fmx}

uses
  FMX.Helpers.Android,
  Androidapi.Helpers,
  Androidapi.JNIBridge,
  Androidapi.JNI.JavaTypes,
  Androidapi.JNI.GraphicsContentViewText,
  Androidapi.JNI.Nfc,
  Androidapi.JNI.Os;

{ TMainForm }
procedure TMainForm.FormActivate(Sender: TObject);
var
  Intent: JIntent;
  TagParcel: JParcelable;
  Tag: JTag;
begin
  Log.d('OnActivate');
  Intent := SharedActivity.getIntent;
  if Intent <> nil then
  begin
    Log.d('Intent action = %s', [JStringToString(Intent.getAction)]);
    if TJNfcAdapter.JavaClass.ACTION_NDEF_DISCOVERED.equals(Intent.getAction) or
       TJNfcAdapter.JavaClass.ACTION_TECH_DISCOVERED.equals(Intent.getAction) or
       TJNfcAdapter.JavaClass.ACTION_TAG_DISCOVERED.equals(Intent.getAction) then
    begin
      Log.d('Getting Tag parcel from the received Intent');
      TagParcel := Intent.getParcelableExtra(TJNfcAdapter.JavaClass.EXTRA_TAG);
      if TagParcel <> nil then
      begin
        Log.d('Wrapping tag from the parcel');
        Tag := TJTag.Wrap((TagParcel as ILocalObject).GetObjectID);
      end;
      InfoLabel.Text := '';
      NFCTagIdLabel.Text := HandleNfcTag(Tag,
        procedure (const Msg: string)
        begin
          Log.d('Adding to UI: ' + Msg);
          InfoLabel.Text := InfoLabel.Text + Msg + LineFeed;
        end);
    end;
  end;
end;

procedure TMainForm.TagWriteButtonClick(Sender: TObject);
var
  NfcAdapter: JNfcAdapter;
  TagParcel: JParcelable;
  Tag: JTag;
  Intent: JIntent;
begin
  NfcAdapter := TJNfcAdapter.JavaClass.getDefaultAdapter(SharedActivityContext);
  if (NfcAdapter <> nil) and NfcAdapter.isEnabled then
  begin
    Intent := SharedActivity.getIntent;
    TagParcel := Intent.getParcelableExtra(TJNfcAdapter.JavaClass.EXTRA_TAG);
    if TagParcel <> nil then
    begin
      Log.d('Wrapping tag from the parcel');
      Tag := TJTag.Wrap((TagParcel as ILocalObject).GetObjectID);
      if not WriteTagText(TagWriteEdit.Text, Tag) then
        raise Exception.Create('Error connecting to tag');
    end;
  end
  else
    raise Exception.Create('NFC is not available');
end;

end.
